@@ -7,12 +7,13 @@ from abc import ABCMeta, abstractmethod
 
 
 class ITimeout(metaclass=ABCMeta):
-    __slots__ = "_st", "_timeout", "_unit"
+    __slots__ = "_st", "_timeout", "_timestamp"
 
     @abstractmethod
     def start(self) -> None:
         raise NotImplementedError()
 
+    @property
     @abstractmethod
     def is_timeout(self) -> bool:
         raise NotImplementedError()
