@@ -5,7 +5,8 @@
 # @Email    : 376355670@qq.com
 from abc import ABCMeta, abstractmethod
 
-from f1z1_common import CoroOrFunction, UnitOfTime, ArgsTypes, KwargsTypes
+from f1z1_common.src.task import CoroOrFunction, ArgsTypes, KwargsTypes
+from f1z1_common.src.time_ import UnitOfTime
 
 from ..components.counter import AsyncCountGenerator
 from ..components.gather import IGather, QueueGather, is_gather
@@ -59,9 +60,9 @@ class AbstractWorkerBuilder(metaclass=ABCMeta):
     def _create_handler(self):
         return WorkerHandler(
             self._target,
-            self._args,
-            self._kwargs,
-            self._thread_workers
+            args=self._args,
+            kwargs=self._kwargs,
+            thread_workers=self._thread_workers
         )
 
     def _check_gather(self, gather):
