@@ -3,15 +3,14 @@
 # @IDE      : PyCharm
 # @Author   : Angel
 # @Email    : 376355670@qq.com
-from f1z1_common import UnitOfTime
-from f1z1_async_runner import create_runner, start
+from f1z1_common.src.time_ import UnitOfTime
 
 from ..components.gather import AwaitBufferQueue, QueueGather, SetGather
 from ..components.record import RecorderChain
 from ..components.speed import Speed, IntOrFloat
-from .base import IWorker, IWorkerFactory
+from .base import IWorkerFactory
 from .builder import Int2E16
-from .worker import WorkerGroup, is_worker
+from .worker import WorkerGroup
 from .master import WorkerMaster
 
 
@@ -45,22 +44,3 @@ class WorkerMasterFactory(IWorkerFactory):
     @classmethod
     def create(cls, maxsize: int = None) -> WorkerMaster:
         return WorkerMaster(SetGather(maxsize), RecorderChain())
-
-
-def create_group(count: int = Int2E16,
-                 speed: IntOrFloat = 10,
-                 speed_unit: UnitOfTime = UnitOfTime.MILLISECOND):
-    return WorkerGroupFactory.create(count, speed, speed_unit)
-
-
-def create_master(maxsize: int = None):
-    return WorkerMasterFactory.create(maxsize)
-
-
-def run(worker: IWorker):
-    if not is_worker(worker):
-        raise ValueError(
-            f"worker need IWorker, but got {type(worker).__name__}"
-        )
-    runner = create_runner(worker.start())
-    return start(runner)
