@@ -4,8 +4,9 @@
 # @Author   : Angel
 # @Email    : 376355670@qq.com
 from abc import ABCMeta, abstractmethod
+from asyncio import AbstractEventLoop
 
-from f1z1_common import ArgsTypes, CoroOrFunction, KwargsTypes, TaskFactory
+from f1z1_common.src.task import ArgsTypes, CoroOrFunction, KwargsTypes, TaskFactory
 
 from ..components.gather import IGather
 
@@ -23,15 +24,17 @@ class WorkerHandler(IWorkerHandler):
 
     def __init__(self,
                  target: CoroOrFunction,
+                 *,
+                 eloop: AbstractEventLoop = None,
                  args: ArgsTypes = None,
                  kwargs: KwargsTypes = None,
                  thread_workers: int = None):
         self._factory = TaskFactory(
-            target, args, kwargs, thread_workers
+            target, eloop=eloop, max_workers=thread_workers, args=args, kwargs=kwargs
         )
 
     def handle(self, gather: IGather):
         gather.put(self._create())
 
     def _create(self):
-        return self._factory.create_task()
+        return self._factory.create()
